==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/template/barnraiser_01/list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=grp_list" method="post" name="frm" id="id_frm">
<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_groups'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($groups)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($groups as $key => $i):
					
					?>
					<tr>
						<td valign="top" width="32" rowspan="3">	
							<a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="" /></a><br />
						</td>
						<td valign="top">
							<b><a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a></b><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $i['group_synopsis'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<i>
							<?php 
							if (isset($i['location_name'])) {
								echo $lang['txt_location'] . ":" . $i['location_name'], ", ";
							}
							?>
							
							<?php 
							if (isset($lang['group_type'][$i['group_type']])) {
								echo $lang['txt_group_type'] . ":" . $lang['group_type'][$i['group_type']] . ",";
							}
							?>
							
							<?php echo $lang['txt_recommended_age'];?>:
							<?php
							if (!empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $i['group_from_age'] . "/" . $i['group_to_age'];
							}
							elseif (!empty($i['group_from_age']) && empty($i['group_to_age'])) {
								echo $lang['txt_age_from'] . " " . $i['group_from_age'];
							}
							else if (empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
							}
							else {
								echo $lang['txt_age_all'];
							}
							?>
							</i>
							<br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
				?>
				<td colspan="2" valign="top">
					<?php echo $lang['template_error']['err_no_items'];?><br />
				</td>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_options'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php
					if (!isset($_REQUEST['view']) && !isset($_POST['search'])) {
					?>
					<?php echo $lang['href_latest_groups'];?><br />
					<?php
					}
					else {
					?>
					<a href="index.php?amn=grp_list"><?php echo $lang['href_latest_groups'];?></a><br />
					<?php }?>
					
					<?php
					if (isset($_REQUEST['view']) && $_REQUEST['view'] == "my_groups") {
					?>
					<?php echo $lang['href_my_groups'];?><br />	
					<?php
					}
					else {
					?>
					<a href="index.php?amn=grp_list&amp;view=my_groups"><?php echo $lang['href_my_groups'];?></a><br />	
					<?php }?>
				</p>
				
				<p>
					<b><?php echo $lang['txt_search'];?></b><br />				
				</p>	

				<p>
					<input type="radio" name="local" value="0" checked="checked" /><?php echo $lang['txt_all'];?></input><br />
					<input type="radio" name="local" value="1" /><?php echo $lang['txt_local'];?></input><br />
				</p>
				
				<p>
					<input type="text" name="search_text" value="" class="input1" /><br />
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="search" class="input_submit" value="<?php echo $lang['sub_search']; ?>" /><br />
				</p>
			</div>
		</div>
	</div>
</div>
</form>

==> am_mod_grp_0_5.zip: am_mod_grp_0_5/components/grp/template/barnraiser_01/list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=grp_list" method="post" name="frm" id="id_frm">
<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_groups'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($groups)) {
				?>
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<?php
					foreach ($groups as $key => $i):
					
					?>
					<tr>
						<td valign="top" width="32" rowspan="3">	
							<a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" class="picture" alt="<?php echo isset($i['image']['file_save_name']) ? $i['image']['file_save_name'] : $lang['alt_no_image']; ?>" /></a><br />
						</td>
						<td valign="top">
							<b><a href="index.php?amn=grp_item&amp;group_id=<?php echo $i['group_id'];?>"><?php echo $i['group_title'];?></a></b><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $i['group_synopsis'];?><br />
						</td>
					</tr>
					<tr>
						<td valign="top">
							<i>
							<?php 
							if (isset($i['location_name'])) {
								echo $lang['txt_location'] . ":" . $i['location_name'], ", ";
							}
							?>
							
							<?php 
							if (isset($lang['group_type'][$i['group_type']])) {
								echo $lang['txt_group_type'] . ":" . $lang['group_type'][$i['group_type']] . ",";
							}
							?>
							
							<?php echo $lang['txt_recommended_age'];?>:
							<?php
							if (!empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $i['group_from_age'] . "/" . $i['group_to_age'];
							}
							elseif (!empty($i['group_from_age']) && empty($i['group_to_age'])) {
								echo $lang['txt_age_from'] . " " . $i['group_from_age'];
							}
							else if (empty($i['group_from_age']) && !empty($i['group_to_age'])) {
								echo $lang['txt_age_upto'] . " " . $i['group_to_age'];
							}
							else {
								echo $lang['txt_age_all'];
							}
							?>
							</i>
							<br />
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="2">
							<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" height="6" width="1" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				}
				else {
				?>
				<td colspan="2" valign="top">
					<?php echo $lang['template_error']['err_no_items'];?><br />
				</td>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_options'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php if (isset($_SESSION['md5'])) { ?>
				<p>
					<?php
					if (!isset($_REQUEST['view']) && !isset($_POST['search'])) {
					?>
					<?php echo $lang['href_latest_groups'];?><br />
					<?php
					}
					else {
					?>
					<a href="index.php?amn=grp_list"><?php echo $lang['href_latest_groups'];?></a><br />
					<?php }?>
					
					<?php
					if (isset($_REQUEST['view']) && $_REQUEST['view'] == "my_groups") {
					?>
					<?php echo $lang['href_my_groups'];?><br />	
					<?php
					}
					else {
					?>
					<a href="index.php?amn=grp_list&amp;view=my_groups"><?php echo $lang['href_my_groups'];?></a><br />	
					<?php }?>
				</p>
				<?php } ?>
				
				<p>
					<b><?php echo $lang['txt_search'];?></b><br />				
				</p>	

				<?php if (isset($_SESSION['md5'])) { ?>
				<p>
					<input type="radio" name="local" value="0" checked="checked" /><?php echo $lang['txt_all'];?></input><br />
					<input type="radio" name="local" value="1" /><?php echo $lang['txt_local'];?></input><br />
				</p>
				<?php } else { ?>
					<input type="hidden" name="local" value="0" />
				<?php } ?>
				<p>
					<input type="text" name="search_text" value="" class="input1" /><br />
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="search" class="input_submit" value="<?php echo $lang['sub_search']; ?>" /><br />
				</p>
			</div>
		</div>
	</div>
</div>
</form>
